Welcome to RoutingBlock's documentation!
==========================================

.. toctree::
    :maxdepth: 1
    :caption: Basics

    getting_started

.. toctree::
    :maxdepth: 1
    :caption: Components

    instance
    solution
    evaluation
    localsearch
    frvcp
    alns
    auxilliary

.. toctree::
    :maxdepth: 1
    :caption: Problem settings

    adptw
    niftw

.. toctree::
    :maxdepth: 1
    :caption: Further Reading

    extension
    examples
    development
    full_api
    references


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`